package edu.nyu.scps.tab;

import android.app.ActionBar;
import android.app.ActionBar.Tab;
import android.app.Activity;
import android.app.Fragment;
import android.app.FragmentTransaction;
import android.content.res.Resources;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.widget.Toast;

public class MyTabActivity extends Activity {
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		final ActionBar actionBar = getActionBar();
		actionBar.setNavigationMode(ActionBar.NAVIGATION_MODE_TABS);
		//Turn on DISPLAY_SHOW_TITLE but don't change any other options.
		actionBar.setDisplayOptions(ActionBar.DISPLAY_SHOW_TITLE, ActionBar.DISPLAY_SHOW_TITLE);

		final Resources resources = getResources();
		final Drawable drawable = resources.getDrawable(R.drawable.ic_tab2);

		ActionBar.Tab tab = actionBar.newTab();
		tab.setText("Tab 1");
		tab.setTabListener(new TabListener(new Tab1Fragment()));
		actionBar.addTab(tab);

		tab = actionBar.newTab();
		tab.setText("Tab 2");
		tab.setIcon(drawable);
		tab.setTabListener(new TabListener(new Tab2Fragment()));
		actionBar.addTab(tab);

		tab = actionBar.newTab();
		tab.setText("Tab 3");
		tab.setTabListener(new TabListener(new Tab3Fragment()));
		actionBar.addTab(tab, true);	//Select this tab.
	}

	/*
	Each callback method gets a FragmentTransaction; if any operations are added
	to the transaction, it will be committed at the end of the full tab switch operation.
	This lets tab switches be atomic without the app needing to track the interactions
	between different tabs.
	This simple implementation does not retain fragment state of the non-visible tabs across
	activity instances.  ApiDemos/App/Fragment/Tabs is a more complete implementation.
	*/

	private class TabListener implements ActionBar.TabListener {
		private Fragment mFragment;

		public TabListener(Fragment fragment) {
			mFragment = fragment;
		}

		@Override
		public void onTabSelected(Tab tab, FragmentTransaction fragmentTransaction) {
			Toast.makeText(MyTabActivity.this, "Selected " + mFragment.toString(), Toast.LENGTH_LONG).show();
			fragmentTransaction.add(android.R.id.tabcontent, mFragment, mFragment.toString());
		}

		@Override
		public void onTabUnselected(Tab tab, FragmentTransaction fragmentTransaction) {
			Toast.makeText(MyTabActivity.this, "Unselected " + mFragment.toString(), Toast.LENGTH_LONG).show();
			fragmentTransaction.remove(mFragment);
		}

		@Override
		public void onTabReselected(Tab tab, FragmentTransaction fragmentTransaction) {
			Toast.makeText(MyTabActivity.this, "Reselected " + mFragment.toString(), Toast.LENGTH_LONG).show();
		}
	}

}